GridConfig class

Immutable grid configuration holding column count and gutter size.

Constructors

GridConfig({required int columns, required double gutter})
Creates a GridConfig with the given column count and gutter size.
const

Properties

columns int
Number of columns in the grid.
final
gutter double
Gap between columns in logical pixels.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited