GridConfig constructor
Creates a GridConfig with the given column count and gutter size.
Implementation
const GridConfig({required this.columns, required this.gutter});
Creates a GridConfig with the given column count and gutter size.
const GridConfig({required this.columns, required this.gutter});